### nova-epics, 0.2.1

* Fix readthedocs build (thanks to John Duggan).

### nova-epics, 0.2.0

* Switch to framework-based API documentation (thanks to John Duggan).

### nova-epics, 0.1.0

* Adds read-only connection to EPICS Tomcat server for pulling instrument status into Trame applications (thanks to John Duggan).
